@@ -36,7 +36,7 @@ Flags:
 	Run: func(ctx *gb.Context, args []string) error {
 		if len(args) != 1 && !deleteAll {
 			return errors.New("delete: import path or --all flag is missing")
-		} else if len(args) == 1 && deleteAll {
+		} else if len(args) >= 1 && deleteAll {
 			return errors.New("delete: you cannot specify path and --all flag at once")
 		}
 
@@ -66,7 +66,7 @@ Flags:
 			}
 
 			if err := fileutils.RemoveAll(filepath.Join(ctx.Projectdir(), "vendor", "src", filepath.FromSlash(path))); err != nil {
-				// TODO(dfc) need to apply vendor.cleanpath here to remove indermediate directories.
+				// TODO(dfc) need to apply vendor.cleanpath here to remove intermediate directories.
 				return errors.Wrap(err, "dependency could not be deleted")
 			}
 		}
