@@ -8,7 +8,7 @@ import (
 
 	"github.com/constabulary/gb"
 	"github.com/constabulary/gb/cmd"
-	"github.com/constabulary/gb/vendor"
+	"github.com/constabulary/gb/internal/vendor"
 )
 
 func init() {
