@@ -27,19 +27,13 @@ See 'go help doc'.
 			if len(args) == 0 {
 				args = append(args, ".")
 			}
-			args = append([]string{filepath.Join(ctx.Context.GOROOT, "bin", "godoc")}, args...)
 
-			cmd := exec.Cmd{
-				Path: args[0],
-				Args: args,
-				Env:  env,
-
-				Stdin:  os.Stdin,
-				Stdout: os.Stdout,
-				Stderr: os.Stderr,
-			}
+			cmd := exec.Command("godoc", args...)
+			cmd.Env = env
+			cmd.Stdout = os.Stdout
+			cmd.Stderr = os.Stderr
 			return cmd.Run()
 		},
-		ParseArgs: func(_ *gb.Context, _ string, args []string) []string { return args },
+		SkipParseArgs: true,
 	})
 }
