@@ -63,9 +63,9 @@ func TestMain(m *testing.M) {
 		}
 		testgb = filepath.Join(dir, testgb)
 		locations := [][]string{
-			[]string{runtime.GOROOT(), "bin", "go"},
-			[]string{runtime.GOROOT(), "..", "bin", "go"},
-			[]string{runtime.GOROOT(), "..", "..", "bin", "go"},
+			{runtime.GOROOT(), "bin", "go"},
+			{runtime.GOROOT(), "..", "bin", "go"},
+			{runtime.GOROOT(), "..", "..", "bin", "go"},
 		}
 		ok := false
 		for _, loc := range locations {
@@ -451,7 +451,7 @@ func (t *T) mustBeEmpty(root string) {
 		found = append(found, path)
 		return nil
 	}
-	err = filepath.Walk(root, fn)
+	filepath.Walk(root, fn)
 	if len(found) > 0 {
 		t.Fatalf("expected %s to be empty, found %s", root, found)
 	}
@@ -1633,10 +1633,6 @@ func main() {
 	tmpdir := gb.tempDir("tmp")
 
 	gb.setenv("TMP", tmpdir)
-	name := "x"
-	if runtime.GOOS == "windows" {
-		name += ".exe"
-	}
 	gb.runFail("build")
 	gb.mustBeEmpty(tmpdir)
 	gb.grepStderr(`FATAL: command "build" failed: failed to resolve import path "x": import "this/is/a/bad/path": not found`, "expected FATAL")
@@ -1720,3 +1716,27 @@ func main() {
 	gb.grepStdout("^pkg2$", "expected pkg2")
 	gb.mustBeEmpty(tmpdir)
 }
+
+func TestIssue680(t *testing.T) {
+	gb := T{T: t}
+	defer gb.cleanup()
+
+	gb.tempFile("src/issue680/issue_test.go", `// +build go1.7
+
+package main
+
+import (
+	"net/http/httptest"
+	"testing"
+)
+
+func TestFoo(t *testing.T) {
+	_ = httptest.NewRequest("", "https://example.com", nil)
+}`)
+	gb.tempFile("src/issue680/test_test.go", "package main")
+
+	gb.cd(gb.tempdir)
+	tmpdir := gb.tempDir("tmp")
+	gb.run("test")
+	gb.mustBeEmpty(tmpdir)
+}
