@@ -4,13 +4,15 @@ import (
 	"fmt"
 	"os"
 	"path/filepath"
+
+	"github.com/pkg/errors"
 )
 
 // FindProjectroot works upwards from path seaching for the
 // src/ directory which identifies the project root.
 func FindProjectroot(path string) (string, error) {
 	if path == "" {
-		return "", fmt.Errorf("project root is blank")
+		return "", errors.New("project root is blank")
 	}
 	start := path
 	for path != filepath.Dir(path) {
