@@ -2,6 +2,7 @@ package gb
 
 import (
 	"fmt"
+	"go/build"
 	"io"
 	"io/ioutil"
 	"os"
@@ -14,24 +15,25 @@ import (
 	"time"
 
 	"github.com/constabulary/gb/internal/debug"
-	"github.com/constabulary/gb/internal/importer"
 	"github.com/pkg/errors"
 )
 
+// enables sh style -e output
+const eMode = false
+
 // Importer resolves package import paths to *importer.Packages.
 type Importer interface {
 
 	// Import attempts to resolve the package import path, path,
 	// to an *importer.Package.
-	Import(path string) (*importer.Package, error)
+	Import(path string) (*build.Package, error)
 }
 
 // Context represents an execution of one or more Targets inside a Project.
 type Context struct {
 	Project
-	*importer.Context // TODO(dfc) this is a hack
 
-	importers []Importer
+	importer Importer
 
 	pkgs map[string]*Package // map of package paths to resolved packages
 
@@ -47,7 +49,7 @@ type Context struct {
 	Force   bool // force rebuild of packages
 	Install bool // copy packages into $PROJECT/pkg
 	Verbose bool // verbose output
-	Nope    bool // command specfic flag, under test it skips the execute action.
+	Nope    bool // command specific flag, under test it skips the execute action.
 	race    bool // race detector requested
 
 	gcflags []string // flags passed to the compiler
@@ -121,9 +123,8 @@ func NewContext(p Project, opts ...func(*Context) error) (*Context, error) {
 	envOr := func(key, def string) string {
 		if v := os.Getenv(key); v != "" {
 			return v
-		} else {
-			return def
 		}
+		return def
 	}
 
 	defaults := []func(*Context) error{
@@ -159,53 +160,41 @@ func NewContext(p Project, opts ...func(*Context) error) (*Context, error) {
 	// sort build tags to ensure the ctxSring and Suffix is stable
 	sort.Strings(ctx.buildtags)
 
-	ic := importer.Context{
-		GOOS:        ctx.gotargetos,
-		GOARCH:      ctx.gotargetarch,
-		CgoEnabled:  cgoEnabled(ctx.gohostos, ctx.gohostarch, ctx.gotargetos, ctx.gotargetarch),
-		ReleaseTags: releaseTags, // from go/build, see gb.go
-		BuildTags:   ctx.buildtags,
-	}
-	ctx.Context = &ic
+	bc := build.Default
+	bc.GOOS = ctx.gotargetos
+	bc.GOARCH = ctx.gotargetarch
+	bc.CgoEnabled = cgoEnabled(ctx.gohostos, ctx.gohostarch, ctx.gotargetos, ctx.gotargetarch)
+	bc.ReleaseTags = releaseTags
+	bc.BuildTags = ctx.buildtags
 
-	ctx.AddImporter(&importer.Importer{
-		Context: &ic,
-		Root:    runtime.GOROOT(),
-	})
-
-	for _, dir := range p.Srcdirs() {
-		ctx.AddImporter(&importer.Importer{
-			Context: &ic,
-			Root:    filepath.Dir(dir), // strip off "src"
-		})
+	i, err := buildImporter(&bc, &ctx)
+	if err != nil {
+		return nil, err
 	}
 
+	ctx.importer = i
+
 	// C and unsafe are fake packages synthesised by the compiler.
 	// Insert fake packages into the package cache.
 	for _, name := range []string{"C", "unsafe"} {
-		pkg, err := newPackage(&ctx, &importer.Package{
+		pkg, err := ctx.newPackage(&build.Package{
 			Name:       name,
 			ImportPath: name,
-			Standard:   true,
 			Dir:        name, // fake, but helps diagnostics
+			Goroot:     true,
 		})
 		if err != nil {
 			return nil, err
 		}
-		pkg.Stale = false
+		pkg.NotStale = true
 		ctx.pkgs[pkg.ImportPath] = pkg
 	}
 
-	return &ctx, nil
-}
-
-// AddImporter adds an additional Importer to the Context.
-func (c *Context) AddImporter(i Importer) {
-	c.importers = append(c.importers, i)
+	return &ctx, err
 }
 
 // IncludePaths returns the include paths visible in this context.
-func (c *Context) IncludePaths() []string {
+func (c *Context) includePaths() []string {
 	return []string{
 		c.workdir,
 		c.Pkgdir(),
@@ -213,12 +202,12 @@ func (c *Context) IncludePaths() []string {
 }
 
 // NewPackage creates a resolved Package for p.
-func (c *Context) NewPackage(p *importer.Package) (*Package, error) {
-	pkg, err := newPackage(c, p)
+func (c *Context) NewPackage(p *build.Package) (*Package, error) {
+	pkg, err := c.newPackage(p)
 	if err != nil {
 		return nil, err
 	}
-	pkg.Stale = isStale(pkg)
+	pkg.NotStale = !pkg.isStale()
 	return pkg, nil
 }
 
@@ -263,7 +252,7 @@ func (c *Context) loadPackage(stack []string, path string) (*Package, error) {
 		return pkg, nil
 	}
 
-	p, err := c.importPackage(path)
+	p, err := c.importer.Import(path)
 	if err != nil {
 		return nil, err
 	}
@@ -283,38 +272,19 @@ func (c *Context) loadPackage(stack []string, path string) (*Package, error) {
 
 		// update the import path as the import may have been discovered via vendoring.
 		p.Imports[i] = pkg.ImportPath
-		stale = stale || pkg.Stale
+		stale = stale || !pkg.NotStale
 	}
 
-	pkg, err := newPackage(c, p)
+	pkg, err := c.newPackage(p)
 	if err != nil {
 		return nil, errors.Wrapf(err, "loadPackage(%q)", path)
 	}
-	pkg.Stale = stale || isStale(pkg)
+	pkg.Main = pkg.Name == "main"
+	pkg.NotStale = !(stale || pkg.isStale())
 	c.pkgs[p.ImportPath] = pkg
 	return pkg, nil
 }
 
-// importPackage loads a package using the backing set of importers.
-func (c *Context) importPackage(path string) (*importer.Package, error) {
-	var err error
-	for i, im := range c.importers {
-		pkg, err2 := im.Import(path)
-		if err2 == nil {
-			return pkg, nil
-		}
-		if i < 2 {
-			err = err2
-		}
-	}
-	switch err.(type) {
-	case *os.PathError:
-		return nil, errors.Wrapf(err, "import %q: not found", path)
-	default:
-		return nil, err
-	}
-}
-
 // Destroy removes the temporary working files of this context.
 func (c *Context) Destroy() error {
 	debug.Debugf("removing work directory: %v", c.workdir)
@@ -338,6 +308,9 @@ func runOut(output io.Writer, dir string, env []string, command string, args ...
 	cmd.Stdout = output
 	cmd.Stderr = os.Stderr
 	cmd.Env = mergeEnvLists(env, envForDir(cmd.Dir))
+	if eMode {
+		fmt.Fprintln(os.Stderr, "+", strings.Join(cmd.Args, " "))
+	}
 	debug.Debugf("cd %s; %s", cmd.Dir, cmd.Args)
 	err := cmd.Run()
 	return err
@@ -442,3 +415,41 @@ func cgoEnabled(gohostos, gohostarch, gotargetos, gotargetarch string) bool {
 		return false
 	}
 }
+
+func buildImporter(bc *build.Context, ctx *Context) (Importer, error) {
+	i, err := addDepfileDeps(bc, ctx)
+	if err != nil {
+		return nil, err
+	}
+
+	// construct importer stack in reverse order, vendor at the bottom, GOROOT on the top.
+	i = &_importer{
+		Importer: i,
+		im: importer{
+			Context: bc,
+			Root:    filepath.Join(ctx.Projectdir(), "vendor"),
+		},
+	}
+
+	i = &srcImporter{
+		i,
+		importer{
+			Context: bc,
+			Root:    ctx.Projectdir(),
+		},
+	}
+
+	i = &_importer{
+		i,
+		importer{
+			Context: bc,
+			Root:    runtime.GOROOT(),
+		},
+	}
+
+	i = &fixupImporter{
+		Importer: i,
+	}
+
+	return i, nil
+}
