@@ -15,14 +15,11 @@ func ExampleNewProject() {
 
 	// Create a new Project passing in the source directories
 	// under this project's root.
-	proj := gb.NewProject(root,
-		gb.SourceDir(filepath.Join(root, "src")),           // $PROJECT/src
-		gb.SourceDir(filepath.Join(root, "vendor", "src")), // $PROJECT/vendor/src
-	)
+	proj := gb.NewProject(root)
 
 	// Create a new Context from the Project. A Context holds
 	// the state of a specific compilation or test within the Project.
-	ctx, err := proj.NewContext()
+	ctx, err := gb.NewContext(proj)
 	if err != nil {
 		log.Fatal("Could not create new context:", err)
 	}
