@@ -3,12 +3,11 @@ package gb
 import (
 	"errors"
 	"fmt"
+	"go/build"
 	"io"
 	"path/filepath"
 	"reflect"
 	"testing"
-
-	"github.com/constabulary/gb/internal/importer"
 )
 
 func TestExecuteBuildAction(t *testing.T) {
@@ -32,7 +31,7 @@ func TestExecuteBuildAction(t *testing.T) {
 		err: errors.New("import cycle detected: x -> y -> x"),
 	}, {
 		pkg: "h", // imports "blank", which is blank, see issue #131
-		err: &importer.NoGoError{filepath.Join(getwd(t), "testdata", "src", "blank")},
+		err: &build.NoGoError{Dir: filepath.Join(getwd(t), "testdata", "src", "blank")},
 	}}
 
 	for _, tt := range tests {
@@ -48,7 +47,7 @@ func TestExecuteBuildAction(t *testing.T) {
 		}
 		action, err := BuildPackages(pkg)
 		if err != nil {
-			t.Errorf("BuildAction(%v): ", tt.pkg, err)
+			t.Errorf("BuildAction(%v): %v", tt.pkg, err)
 			continue
 		}
 		if err := Execute(action); !reflect.DeepEqual(err, tt.err) {
@@ -77,10 +76,10 @@ var executorTests = []struct {
 	action: &Action{
 		Name: "child, child, error",
 		Run:  func() error { return fmt.Errorf("I should not have been called") },
-		Deps: []*Action{&Action{
+		Deps: []*Action{{
 			Name: "child, error",
 			Run:  niltask,
-			Deps: []*Action{&Action{
+			Deps: []*Action{{
 				Name: "error",
 				Run:  func() error { return io.EOF },
 			}},
