@@ -20,24 +20,16 @@ type Project interface {
 	Pkgdir() string
 
 	// Bindir returns the path for compiled programs.
-	Bindir() string
-
-	// Srcdirs returns the path to the source directories.
-	Srcdirs() []string
+	bindir() string
 }
 
 type project struct {
 	rootdir string
-	srcdirs []string
 }
 
 func NewProject(root string) Project {
 	proj := project{
 		rootdir: root,
-		srcdirs: []string{
-			filepath.Join(root, "src"),
-			filepath.Join(root, "vendor", "src"),
-		},
 	}
 	return &proj
 }
@@ -52,15 +44,7 @@ func (p *project) Projectdir() string {
 	return p.rootdir
 }
 
-// Srcdirs returns the path to the source directories.
-// The first source directory will always be
-// filepath.Join(Projectdir(), "src")
-// but there may be additional directories.
-func (p *project) Srcdirs() []string {
-	return p.srcdirs
-}
-
 // Bindir returns the path for compiled programs.
-func (p *project) Bindir() string {
+func (p *project) bindir() string {
 	return filepath.Join(p.rootdir, "bin")
 }
